@@ -4,11 +4,11 @@ import sys
 import os
 import requests
 sys.path.append(os.path.join(os.path.dirname(__file__)))
-from .resources.test_resource import TestResource
-from .resources.operation_resource import OperationResource
-from .resources.state_resource import StateResource
-from .resources.remote_resource import RemoteResource
-from .resources.benchmark_resource import BenchmarkResource
+from resources.test_resource import TestResource
+from resources.operation_resource import OperationResource
+from resources.state_resource import StateResource
+from resources.remote_resource import RemoteResource
+from resources.benchmark_resource import BenchmarkResource
 
 
 class RestClient(object):
@@ -20,6 +20,3 @@ class RestClient(object):
         self.state = StateResource(host, port, __session, time_out=time_out)
         self.remote = RemoteResource(host, port)
         self.benchmark = BenchmarkResource(host, port, __session, time_out)
-
-if __name__ == '__main__':
-    pass
